<?php

namespace Drupal\lametric\Service;

use Drupal\Component\Serialization\SerializationInterface;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\RequestOptions;

/**
 * Class LaMetricNotification.
 *
 * @package Drupal\lametric\Service
 */
class LaMetricNotification implements LaMetricNotificationInterface {

  /**
   * A guzzle http client instance.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * The JSON serialization.
   *
   * @var \Drupal\Component\Serialization\SerializationInterface
   */
  protected $jsonSerialization;

  /**
   * LaMetricNotification constructor.
   *
   * @param \GuzzleHttp\ClientInterface $http_client
   *   The Guzzle HTTP client instance.
   * @param \Drupal\Component\Serialization\SerializationInterface $json_serialization
   *   The JSON serialization.
   */
  public function __construct(
    ClientInterface $http_client,
    SerializationInterface $json_serialization
  ) {
    $this->httpClient = $http_client;
    $this->jsonSerialization = $json_serialization;
  }

  /**
   * {@inheritdoc}
   */
  public function send($ip, $key, $text, $icon = NULL) {
    $frame = ['text' => $text];

    if ($icon !== NULL) {
      $frame['icon'] = $icon;
    }

    try {
      $request = $this->httpClient->post(
        sprintf('http://%s:8080/api/v2/device/notifications', $ip),
        [
          RequestOptions::AUTH => ['dev', $key],
          RequestOptions::JSON => [
            'model' => [
              'frames' => [$frame],
            ],
          ],
        ]
      );

      $response = $request->getBody()->getContents();
      $content = $this->jsonSerialization->decode($response);

      if (
        isset($content['success']) &&
        is_array($content['success']) &&
        isset($content['success']['id']) &&
        is_numeric($content['success']['id'])
      ) {
        return (int) $content['success']['id'];
      }
      else {
        return $response;
      }
    }
    catch (\Exception $exception) {
      return $exception;
    }
  }

}
